@@ -249,12 +249,28 @@ class DataTypes:
         return DataTypes.type({
             'type': 'list',
             'schema': schema,
+            'iduplicated': True,
+            'iempty': True,
             'message': {
                 lang.EN: "{name} must be a list",
                 lang.ES: "{name} debe ser una lista",
             }
         }, ptyp2)
 
+    @staticmethod
+    def str_list(schema: dict, ptyp2: dict or None = None) -> dict:
+        return DataTypes.list({
+            'schema': schema,
+            'cast': {
+                'type': 'str',
+                'join': ','
+            },
+            'message': {
+                lang.EN: "{name} must be a string comma-separated list",
+                lang.ES: "{name} debe ser una lista de elementos separados por comas",
+            }
+        }, ptyp2)
+
     @staticmethod
     def dict(ptyp2: dict or None = None) -> dict:
         return DataTypes.type({
